@@ -1,40 +1,22 @@
 /*
 * Copyright 2017 Huy Cuong Nguyen
 * Copyright 2016 ZXing authors
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-*      http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
 */
+// SPDX-License-Identifier: Apache-2.0
 
 #include "DecoderResult.h"
-#include "DecodeStatus.h"
-#include "pdf417/PDFDecodedBitStreamParser.h"
+#include "pdf417/PDFDecoder.h"
 #include "pdf417/PDFDecoderResultExtra.h"
 
 #include "gtest/gtest.h"
 
-namespace ZXing { namespace Pdf417 {
-	DecodeStatus DecodeMacroBlock(const std::vector<int>& codewords, int codeIndex, DecoderResultExtra& resultMetadata, int& next);
-}}
+namespace ZXing::Pdf417 {
+int DecodeMacroBlock(const std::vector<int>& codewords, int codeIndex, DecoderResultExtra& resultMetadata);
+}
 
 using namespace ZXing;
 using namespace ZXing::Pdf417;
 
-// Shorthand for Decode()
-static DecoderResult parse(const std::vector<int>& codewords, int ecLevel = 0, const std::string& characterSet = "")
-{
-	return DecodedBitStreamParser::Decode(codewords, ecLevel, characterSet);
-}
-
 /**
 * Tests the first sample given in ISO/IEC 15438:2015(E) - Annex H.4
 */
@@ -44,10 +26,8 @@ TEST(PDF417DecoderTest, StandardSample1)
 		// we should never reach these
 		1000, 1000, 1000 };
 
-	int next = 0;
 	DecoderResultExtra resultMetadata;
-	auto status = DecodeMacroBlock(sampleCodes, 2, resultMetadata, next);
-	EXPECT_EQ(status, DecodeStatus::NoError);
+	DecodeMacroBlock(sampleCodes, 2, resultMetadata);
 
 	EXPECT_EQ(0, resultMetadata.segmentIndex());
 	EXPECT_EQ("017053", resultMetadata.fileId());
@@ -60,7 +40,7 @@ TEST(PDF417DecoderTest, StandardSample1)
 	EXPECT_EQ(1, optionalData.front()) << "first element of optional array should be the first field identifier";
 	EXPECT_EQ(67, optionalData.back()) << "last element of optional array should be the last codeword of the last field";
 
-	auto result = parse(sampleCodes);
+	auto result = Decode(sampleCodes);
 
 	EXPECT_EQ(0, result.structuredAppend().index);
 	EXPECT_EQ("017053", result.structuredAppend().id);
@@ -76,10 +56,8 @@ TEST(PDF417DecoderTest, StandardSample2)
 		// we should never reach these
 		1000, 1000, 1000 };
 
-	int next = 0;
 	DecoderResultExtra resultMetadata;
-	auto status = DecodeMacroBlock(sampleCodes, 2, resultMetadata, next);
-	EXPECT_EQ(status, DecodeStatus::NoError);
+	DecodeMacroBlock(sampleCodes, 2, resultMetadata);
 
 	EXPECT_EQ(3, resultMetadata.segmentIndex());
 	EXPECT_EQ("017053", resultMetadata.fileId());
@@ -92,7 +70,7 @@ TEST(PDF417DecoderTest, StandardSample2)
 	EXPECT_EQ(1, optionalData.front()) << "first element of optional array should be the first field identifier";
 	EXPECT_EQ(104, optionalData.back()) << "last element of optional array should be the last codeword of the last field";
 
-	auto result = parse(sampleCodes);
+	auto result = Decode(sampleCodes);
 
 	EXPECT_EQ(3, result.structuredAppend().index);
 	EXPECT_EQ("017053", result.structuredAppend().id);
@@ -106,16 +84,14 @@ TEST(PDF417DecoderTest, StandardSample3)
 {
 	std::vector<int> sampleCodes = { 7, 928, 111, 100, 100, 200, 300 };
 
-	int next = 0;
 	DecoderResultExtra resultMetadata;
-	auto status = DecodeMacroBlock(sampleCodes, 2, resultMetadata, next);
-	EXPECT_EQ(status, DecodeStatus::NoError);
+	DecodeMacroBlock(sampleCodes, 2, resultMetadata);
 
 	EXPECT_EQ(0, resultMetadata.segmentIndex());
 	EXPECT_EQ("100200300", resultMetadata.fileId());
 	EXPECT_EQ(-1, resultMetadata.segmentCount());
 
-	auto result = parse(sampleCodes);
+	auto result = Decode(sampleCodes);
 
 	EXPECT_EQ(0, result.structuredAppend().index);
 	EXPECT_EQ("100200300", result.structuredAppend().id);
@@ -128,10 +104,8 @@ TEST(PDF417DecoderTest, SampleWithFilename)
 		599, 923, 1, 111, 102, 98, 311, 355, 522, 920, 779, 40, 628, 33, 749, 267, 506, 213, 928, 465, 248, 493, 72,
 		780, 699, 780, 493, 755, 84, 198, 628, 368, 156, 198, 809, 19, 113 };
 
-	int next = 0;
 	DecoderResultExtra resultMetadata;
-	auto status = DecodeMacroBlock(sampleCodes, 3, resultMetadata, next);
-	EXPECT_EQ(status, DecodeStatus::NoError);
+	DecodeMacroBlock(sampleCodes, 3, resultMetadata);
 
 	EXPECT_EQ(0, resultMetadata.segmentIndex());
 	EXPECT_EQ("000252021086", resultMetadata.fileId());
@@ -141,7 +115,7 @@ TEST(PDF417DecoderTest, SampleWithFilename)
 	EXPECT_EQ("", resultMetadata.addressee());
 	EXPECT_EQ("filename.txt", resultMetadata.fileName());
 
-	auto result = parse(sampleCodes);
+	auto result = Decode(sampleCodes);
 
 	EXPECT_EQ(0, result.structuredAppend().index);
 	EXPECT_EQ("000252021086", result.structuredAppend().id);
@@ -153,10 +127,8 @@ TEST(PDF417DecoderTest, SampleWithNumericValues)
 	std::vector<int> sampleCodes = { 25, 477, 928, 111, 100, 0, 252, 21, 86, 923, 2, 2, 0, 1, 0, 0, 0, 923, 5, 130,
 		923, 6, 1, 500, 13 };
 
-	int next = 0;
 	DecoderResultExtra resultMetadata;
-	auto status = DecodeMacroBlock(sampleCodes, 3, resultMetadata, next);
-	EXPECT_EQ(status, DecodeStatus::NoError);
+	DecodeMacroBlock(sampleCodes, 3, resultMetadata);
 
 	EXPECT_EQ(0, resultMetadata.segmentIndex());
 	EXPECT_EQ("000252021086", resultMetadata.fileId());
@@ -167,7 +139,7 @@ TEST(PDF417DecoderTest, SampleWithNumericValues)
 	EXPECT_EQ(260013, resultMetadata.checksum());
 	EXPECT_EQ(-1, resultMetadata.segmentCount());
 
-	auto result = parse(sampleCodes);
+	auto result = Decode(sampleCodes);
 
 	EXPECT_EQ(0, result.structuredAppend().index);
 	EXPECT_EQ("000252021086", result.structuredAppend().id);
@@ -178,17 +150,15 @@ TEST(PDF417DecoderTest, SampleWithMacroTerminatorOnly)
 {
 	std::vector<int> sampleCodes = { 7, 477, 928, 222, 198, 0, 922 };
 
-	int next = 0;
 	DecoderResultExtra resultMetadata;
-	auto status = DecodeMacroBlock(sampleCodes, 3, resultMetadata, next);
-	EXPECT_EQ(status, DecodeStatus::NoError);
+	DecodeMacroBlock(sampleCodes, 3, resultMetadata);
 
 	EXPECT_EQ(99998, resultMetadata.segmentIndex());
 	EXPECT_EQ("000", resultMetadata.fileId());
 	EXPECT_EQ(true, resultMetadata.isLastSegment());
 	EXPECT_EQ(-1, resultMetadata.segmentCount());
 
-	auto result = parse(sampleCodes);
+	auto result = Decode(sampleCodes);
 
 	EXPECT_EQ(99998, result.structuredAppend().index);
 	EXPECT_EQ("000", result.structuredAppend().id);
@@ -198,13 +168,13 @@ TEST(PDF417DecoderTest, SampleWithMacroTerminatorOnly)
 // Shorthand to decode and return text
 static std::wstring decode(const std::vector<int>& codewords)
 {
-	return parse(codewords).text();
+	return Decode(codewords).text();
 }
 
 // Shorthand to decode and return isValid
 static bool valid(const std::vector<int>& codewords)
 {
-	return parse(codewords).isValid();
+	return Decode(codewords).isValid();
 }
 
 TEST(PDF417DecoderTest, TextCompactionSimple)
@@ -519,7 +489,8 @@ TEST(PDF417DecoderTest, ECIMultipleNumeric)
 
 TEST(PDF417DecoderTest, ECIInvalid)
 {
-	EXPECT_EQ(decode({ 4, 927, 901, 0 }), L"AA"); // Invalid Character Set ECI (> 899) silently ignored
+	EXPECT_EQ(decode({ 4, 927, 901, 0 }), L""); // non-charset ECI > 899 -> empty text result
+	EXPECT_EQ(Decode({4, 927, 901, 0}).content().bytes, ByteArray("AA")); // non-charset ECI > 899 -> ignored in binary result
 	EXPECT_EQ(decode({ 3, 0, 927 }), L"AA"); // Malformed ECI at end silently ignored
 }
 
@@ -532,10 +503,8 @@ TEST(PDF417DecoderTest, ECIMacroOptionalNumeric)
 	std::vector<int> sampleCodes = { 19, 477, 928, 111, 100, 0, 252, 21, 86, 923, 5, 15, 369, 753, 190, 927, 25, 124,
 		745 };
 
-	int next = 0;
 	DecoderResultExtra resultMetadata;
-	auto status = DecodeMacroBlock(sampleCodes, 3, resultMetadata, next);
-	EXPECT_EQ(status, DecodeStatus::NoError);
+	DecodeMacroBlock(sampleCodes, 3, resultMetadata);
 
 	EXPECT_EQ(0, resultMetadata.segmentIndex());
 	EXPECT_EQ("000252021086", resultMetadata.fileId());
@@ -563,21 +532,21 @@ TEST(PDF417DecoderTest, ECIUserDefined)
 TEST(PDF417DecoderTest, ReaderInit)
 {
 	// Null
-	EXPECT_FALSE(parse({ 2, 0 }).readerInit());
+	EXPECT_FALSE(Decode({2, 0}).readerInit());
 	EXPECT_EQ(decode({ 2, 0 }), L"AA");
 
 	// Set
-	EXPECT_TRUE(parse({ 3, 921, 0 }).readerInit());
+	EXPECT_TRUE(Decode({3, 921, 0}).readerInit());
 	EXPECT_EQ(decode({ 3, 921, 0 }), L"AA");
 
 	// Must be first
-	EXPECT_FALSE(parse({ 3, 0, 921 }).readerInit());
+	EXPECT_FALSE(Decode({3, 0, 921}).readerInit());
 	EXPECT_FALSE(valid({ 3, 0, 921 }));
 
-	EXPECT_FALSE(parse({ 4, 901, 65, 921 }).readerInit());
+	EXPECT_FALSE(Decode({4, 901, 65, 921}).readerInit());
 	EXPECT_FALSE(valid({ 4, 901, 65, 921 }));
 
-	EXPECT_FALSE(parse({ 4, 901, 921, 65 }).readerInit());
+	EXPECT_FALSE(Decode({4, 901, 921, 65}).readerInit());
 	EXPECT_FALSE(valid({ 4, 901, 921, 65 }));
 }
 
